==> getdp-1.1.2-source.tgz: getdp-1.1.2/Main/Message.h <==
/*
 * Copyright (C) 1997-2005 P. Dular, C. Geuzaine
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 *
 * Please report all bugs and problems to <getdp@geuz.org>.
 */

#ifndef _MESSAGE_H_
#define _MESSAGE_H_

#include <stdarg.h>

/* Message levels */ 

#define DIRECT       0
#define ERROR        1
#define GERROR         1 /* for Windows/Gmsh compatibility */
#define BIGERROR     2
#define WARNING      3
#define OPERATION    4
#define INFO         5
#define INFO1        6
#define INFO2        7
#define INFO3        8
#define BIGINFO      9
#define SPARSKIT     10
#define PETSC        11
#define ITER         12
#define DEBUG        13
#define GDEBUG          13 /* for Windows/Gmsh compatibility */
#define DEBUG2       14
#define LOADING      15
#define RESOURCES    16
#define SUMMARY      17
#define CHECK        18

#define WHITE_INDENT  12
#define WHITE_STR     "            "
#define ERROR_STR     "Error     : "
#define WARNING_STR   "Warning   : "
#define SPARSKIT_STR  "Solver    : "
#define PETSC_STR     "PETSc     : "
#define OPERATION_STR "Operation : "
#define INFO_STR      "Info      : "
#define BIGINFO_STR   "Info      : "
#define LOADING_STR   "Loading   : "
#define RESOURCES_STR "Resources : "
#define SUMMARY_STR   "Resources : "

void Info(int level, char *arg0);
void Signal(int signum);
void Msg(int level, char *fmt, ...);
void Progress(int current, int final, char *label);
void Debug(void);
void CheckResources(void);

#endif

==> getdp-1.2.1-source.tgz: getdp-1.2.1/Main/Message.h <==
/*
 * Copyright (C) 1997-2006 P. Dular, C. Geuzaine
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 *
 * Please report all bugs and problems to <getdp@geuz.org>.
 */

#ifndef _MESSAGE_H_
#define _MESSAGE_H_

#include <stdarg.h>

/* Message levels */ 

#define DIRECT       0
#define GERROR       1
#define BIGERROR     2
#define WARNING      3
#define OPERATION    4
#define INFO         5
#define INFO1        6
#define INFO2        7
#define INFO3        8
#define BIGINFO      9
#define SPARSKIT     10
#define PETSC        11
#define ITER         12
#define DEBUG        13
#define DEBUG2       14
#define LOADING      15
#define RESOURCES    16
#define SUMMARY      17
#define CHECK        18

#define WHITE_INDENT  12
#define WHITE_STR     "            "
#define ERROR_STR     "Error     : "
#define WARNING_STR   "Warning   : "
#define SPARSKIT_STR  "Solver    : "
#define PETSC_STR     "PETSc     : "
#define OPERATION_STR "Operation : "
#define INFO_STR      "Info      : "
#define BIGINFO_STR   "Info      : "
#define LOADING_STR   "Loading   : "
#define RESOURCES_STR "Resources : "
#define SUMMARY_STR   "Resources : "

void Info(int level, char *arg0);
void Signal(int signum);
void Msg(int level, char *fmt, ...);
void Progress(int current, int final, char *label);
void Debug(void);

#endif
